@@ -1,6 +1,6 @@
 // IdleLogManager.cc
 //
-// Copyright (C) 2003, 2004 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2003, 2004, 2005 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 // 
 
-static const char rcsid[] = "$Id: IdleLogManager.cc,v 1.3 2004/05/18 19:19:45 rcaelers Exp $";
+static const char rcsid[] = "$Id: IdleLogManager.cc,v 1.5 2005/04/23 19:53:01 rcaelers Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -26,15 +26,16 @@ static const char rcsid[] = "$Id: IdleLogManager.cc,v 1.3 2004/05/18 19:19:45 rc
 #include <fstream>
 #include <sstream>
 #include <assert.h>
+#include <unistd.h>
 
 #include "Util.hh"
 #include "IdleLogManager.hh"
 #include "TimeSource.hh"
 #include "PacketBuffer.hh"
 
-#define IDLELOG_MAXSIZE 	(4000)
+#define IDLELOG_MAXSIZE 		(4000)
 #define IDLELOG_MAXAGE		(12 * 60 * 60)
-#define IDLELOG_INTERVAL	(30 * 60)
+#define IDLELOG_INTERVAL		(30 * 60)
 #define IDLELOG_OLDVERSION	(1)
 #define IDLELOG_VERSION		(2)
 #define IDLELOG_INTERVAL_SIZE	(17)
@@ -594,7 +595,11 @@ IdleLogManager::unlink_idlelog(PacketBuffer &buffer) const
           ss << Util::get_home_directory();
           ss << "idlelog." << id << ".log" << ends;
           
+#ifdef WIN32
+          _unlink(ss.str().c_str());
+#else
           unlink(ss.str().c_str());
+#endif
           
           g_free(id);
         }
@@ -710,7 +715,7 @@ IdleLogManager::load_index()
         }
       else if (version == IDLELOG_OLDVERSION)
         {
-          TRACE_MSG("Version - deleting logs of old version");
+          TRACE_MSG("Old version - deleting logs of old version");
 
           char *id = buffer.unpack_string();
           if (id != NULL)
@@ -1040,7 +1045,10 @@ IdleLogManager::fix_idlelog(ClientInfo &info)
     {
       IdleInterval &idle = *i;
 
-      TRACE_MSG(idle.begin_time << " " << idle.end_idle_time << " " << idle.active_time);
+      TRACE_MSG(idle.begin_time << " "
+                << idle.end_time << " "
+                << idle.end_idle_time << " "
+                << idle.active_time);
 
       if (next_time == -1)
         {
