@@ -1,6 +1,6 @@
 // Timer.cc --- break timer
 //
-// Copyright (C) 2001, 2002, 2003, 2004 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2001, 2002, 2003, 2004, 2006 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: Timer.cc,v 1.7 2004/10/31 19:21:45 rcaelers Exp $";
+static const char rcsid[] = "$Id: Timer.cc,v 1.9 2006/05/12 20:59:43 rcaelers Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -275,7 +275,7 @@ Timer::compute_next_limit_time()
           // limit-reached event 'snooze_interval' seconds after the previous
           // event. Unless snoozing is inhibted. This is independent of
           // user activity.
-          
+           
           if (!snooze_inhibited)
             {
               next_limit_time = last_limit_time + snooze_interval;
@@ -424,6 +424,7 @@ Timer::start_timer()
       // Set last start and stop times.
       if (!timer_frozen)
         {
+          TRACE_MSG("!Frozen");
           // Timer is not frozen, so let's start.
           last_start_time = time_source->get_time();
           elapsed_idle_time = 0;
@@ -431,7 +432,7 @@ Timer::start_timer()
       else
         {
           // The timer is frozen, so we don't start counting 'active' time.
-          // Instead, update the elasped idle time. 
+          // Instead, update the elapsed idle time. 
           if (last_stop_time != 0)
             {
               elapsed_idle_time += (time_source->get_time() - last_stop_time);
@@ -447,6 +448,7 @@ Timer::start_timer()
       timer_state = STATE_RUNNING;
 
       // When to generate a limit-reached-event.
+      TRACE_MSG("Compute");
       compute_next_limit_time();
     }
   TRACE_EXIT();
@@ -544,6 +546,8 @@ Timer::freeze_timer(bool freeze)
             {
               last_start_time = time_source->get_time();
               elapsed_idle_time = 0;
+
+              compute_next_limit_time();
             }
         }
     }
@@ -722,6 +726,12 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
     }
   
   activity_state = new_activity_state;
+          TRACE_MSG("time, next limit "
+                    << current_time << " "
+                    << next_limit_time << " "
+                    << limit_interval << " "
+                    << (next_limit_time - current_time)
+                    );
   TRACE_MSG("activity_state = " << activity_state);
 
   if (autoreset_interval_predicate &&
