@@ -1,9 +1,9 @@
 // X11InputMonitor.cc --- ActivityMonitor for X11
 //
-// Copyright (C) 2001, 2002, 2003, 2004 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
-// Time-stamp: <2004-07-01 20:25:14 robc>
+// Time-stamp: <2006-01-22 14:13:40 robc>
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: X11InputMonitor.cc,v 1.2 2004/07/01 18:32:13 rcaelers Exp $";
+static const char rcsid[] = "$Id: X11InputMonitor.cc,v 1.7 2006/01/22 13:13:48 rcaelers Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -44,6 +44,9 @@ static const char rcsid[] = "$Id: X11InputMonitor.cc,v 1.2 2004/07/01 18:32:13 r
 # include <unistd.h>
 #endif
 
+// Solaris needs this...
+#define NEED_EVENTS
+
 #include <X11/X.h>
 #include <X11/Xproto.h>
 #include <X11/Xlib.h>
