@@ -13,7 +13,7 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// $Id: System.cc,v 1.9 2006/01/22 16:44:28 rcaelers Exp $
+// $Id: System.cc,v 1.10 2006/02/04 14:21:55 rcaelers Exp $
 //
 
 #include "config.h"
@@ -206,6 +206,10 @@ System::init(
       xlock = g_strdup_printf("%s -display \"%s\"",
                               lock, display);
     }
+  else if ((lock = g_find_program_in_path("gnome-screensaver-command")))
+    {
+      xlock = g_strdup_printf("%s --lock", lock);
+    }
   g_free(lock);
   
   if (xlock != NULL)
