@@ -1,6 +1,6 @@
 // BreakWindow.cc --- base class for the break windows
 //
-// Copyright (C) 2001, 2002, 2003, 2004 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: BreakWindow.cc,v 1.6 2004/04/29 19:49:58 rcaelers Exp $";
+static const char rcsid[] = "$Id: BreakWindow.cc,v 1.13 2005/07/04 19:52:27 rcaelers Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -57,6 +57,7 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
                      : Gtk::WINDOW_POPUP),
          block_mode(mode),
          ignorable_break(ignorable),
+         frame(NULL),
          break_response(NULL),
          gui(NULL)
 {
@@ -110,9 +111,19 @@ BreakWindow::init_gui()
         {
           set_border_width(0);
           Frame *window_frame = manage(new Frame());
-          window_frame->set_border_width(12);
+          window_frame->set_border_width(0);
           window_frame->set_frame_style(Frame::STYLE_BREAK_WINDOW);
-          window_frame->add(*gui);
+
+          frame = manage(new Frame());
+          frame->set_frame_style(Frame::STYLE_SOLID);
+          frame->set_frame_width(6);
+          frame->set_border_width(6);
+          frame->set_frame_flashing(0);
+          frame->set_frame_visible(false);
+
+          window_frame->add(*frame);
+          frame->add(*gui);
+
           if (block_mode == GUI::BLOCK_MODE_ALL)
             {
 #ifdef WIN32
@@ -155,6 +166,12 @@ BreakWindow::init_gui()
 BreakWindow::~BreakWindow()
 {
   TRACE_ENTER("BreakWindow::~BreakWindow");
+
+  if (frame != NULL)
+    {
+      frame->set_frame_flashing(0);
+    }
+  
 #ifdef WIN32
   delete desktop_window;
 #endif
@@ -235,6 +252,7 @@ BreakWindow::create_postpone_button()
 }
 
 
+
 //! The lock button was clicked.
 void
 BreakWindow::on_lock_button_clicked()
@@ -265,6 +283,7 @@ BreakWindow::on_delete_event(GdkEventAny *)
   return TRUE;
 }
 
+
 //! Break response
 inline void
 BreakWindow::set_response(BreakResponseInterface *bri)
@@ -272,14 +291,17 @@ BreakWindow::set_response(BreakResponseInterface *bri)
   break_response = bri;
 }
 
+
 //! The postpone button was clicked.
 void
 BreakWindow::on_postpone_button_clicked()
 {
+  TRACE_ENTER("BreakWindow::on_postpone_button_clicked");
   if (break_response != NULL)
     {
       break_response->postpone_break(break_id);
     }
+  TRACE_EXIT();
 }
 
 
@@ -295,6 +317,7 @@ BreakWindow::on_skip_button_clicked()
 }
 
 
+
 //! Control buttons.
 Gtk::HButtonBox *
 BreakWindow::create_break_buttons(bool lockable,
@@ -310,12 +333,13 @@ BreakWindow::create_break_buttons(bool lockable,
       if (shutdownable)
         {
           shutdown_button = create_shutdown_button();
+          if (shutdown_button != NULL)
+            {
+              box->pack_end(*shutdown_button, Gtk::SHRINK, 0);
+            }
         }
-      if (shutdown_button != NULL)
-        {
-          box->pack_end(*shutdown_button, Gtk::SHRINK, 0);
-        }
-      else if (lockable)
+
+      if (lockable)
         {
           Gtk::Button *lock_button = create_lock_button();
           if (lock_button != NULL)
@@ -367,6 +391,11 @@ BreakWindow::stop()
 {
   TRACE_ENTER("BreakWindow::stop");
 
+  if (frame != NULL)
+    {
+      frame->set_frame_flashing(0);
+    }
+  
   hide_all();
 #ifdef WIN32
   if (desktop_window)
@@ -393,6 +422,9 @@ BreakWindow::destroy()
 void
 BreakWindow::refresh()
 {
+#ifdef WIN32
+  WindowHints::set_always_on_top(Gtk::Widget::gobj(), true);
+#endif
 }
 
 Glib::RefPtr<Gdk::Window>
