@@ -1,6 +1,6 @@
 // GtkUtil.cc --- Gtk utilities
 //
-// Copyright (C) 2003, 2004 Raymond Penners <raymond@dotsphinx.com>
+// Copyright (C) 2003, 2004, 2005 Raymond Penners <raymond@dotsphinx.com>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -13,7 +13,7 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// $Id: GtkUtil.cc,v 1.5 2004/07/13 20:04:52 dotsphinx Exp $
+// $Id: GtkUtil.cc,v 1.9 2005/09/23 19:22:33 rcaelers Exp $
 //
 
 #ifdef HAVE_CONFIG_H
@@ -33,6 +33,7 @@
 #include "Util.hh"
 #include "GtkUtil.hh"
 #include "EventLabel.hh"
+#include "EventImage.hh"
 #include "HeadInfo.hh"
 
 bool
@@ -99,7 +100,8 @@ GtkUtil::update_custom_stock_button(Gtk::Button *btn,
 
 Gtk::Button *
 GtkUtil::create_image_button(const char *label_text,
-                             const char *image_file)
+                             const char *image_file,
+                             bool label)
 {
   Gtk::Button *btn = new Gtk::Button();
   Gtk::Image *img = NULL;
@@ -109,7 +111,12 @@ GtkUtil::create_image_button(const char *label_text,
                                              Util::SEARCH_PATH_IMAGES);
       img = manage(new Gtk::Image(icon));
     }
-  if (label_text != NULL)
+  else
+    {
+      /* Button witout images must have a label */
+      label = true;
+    }
+  if (label_text != NULL && label)
     {
       Gtk::Label *label = manage(new Gtk::Label(label_text));
       Gtk::HBox *hbox = manage(new Gtk::HBox(false, 2));
@@ -193,6 +200,7 @@ Gtk::Widget *
 GtkUtil::create_label_with_tooltip(string text, string tooltip)
 {
 #if 0
+  // This doesn't (didn't ?) work.
   Gtk::Label *label = Gtk::manage(new Gtk::Label(text));
   Gtk::EventBox *eventbox = Gtk::manage(new Gtk::EventBox());
   eventbox->add(*label);
@@ -207,6 +215,17 @@ GtkUtil::create_label_with_tooltip(string text, string tooltip)
 #endif
 }
 
+
+EventImage *
+GtkUtil::create_image_with_tooltip(string file, string tooltip)
+{
+  EventImage *image = Gtk::manage(new EventImage(file));
+  
+  GUI::get_instance()->get_tooltips()->set_tip(*image, tooltip);
+  return image;
+}
+
+
 Gtk::Label *
 GtkUtil::create_label(string text, bool bold)
 {
