@@ -1,6 +1,6 @@
 // Menus.cc --- Timer info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: Menus.cc,v 1.17 2005/04/25 18:56:23 rcaelers Exp $";
+static const char rcsid[] = "$Id: Menus.cc,v 1.19 2006/04/25 21:27:53 rcaelers Exp $";
 
 #include "preinclude.h"
 
@@ -705,14 +705,16 @@ Menus::on_menu_about()
     "Morten Lunde <morten.lunde@broadpark.no>\n"
     "Juraj Kubelka <Juraj.Kubelka@email.cz>\n"
     "Artūras Šlajus <x11@h2o.sky.lt>\n"
-    "Haggai Eran <he3@bezeqint.net>\n";
+    "Haggai Eran <he3@bezeqint.net>\n"
+    "Jordi Mallach <jordi@sindominio.net>\n"
+    "Daniel Nylander <info@danielnylander.se>\n";
 
   string icon = Util::complete_directory("workrave.png",
                                          Util::SEARCH_PATH_IMAGES);
   GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file(icon.c_str(), NULL); 
   gtk_widget_show (gnome_about_new
                    ("Workrave", VERSION,
-                    "Copyright 2001-2005 Rob Caelers & Raymond Penners",
+                    "Copyright 2001-2006 Rob Caelers & Raymond Penners",
                     _("This program assists in the prevention and recovery"
                       " of Repetitive Strain Injury (RSI)."),
                     (const gchar **) authors,
