@@ -1,6 +1,6 @@
 // RestBreakWindow.cc --- window for the microbreak
 //
-// Copyright (C) 2001, 2002, 2003, 2004 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 //
@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: RestBreakWindow.cc,v 1.4 2004/04/03 15:55:33 rcaelers Exp $";
+static const char rcsid[] = "$Id: RestBreakWindow.cc,v 1.11 2005/07/06 19:21:24 rcaelers Exp $";
 
 const int TIMEOUT = 1000;
 
@@ -45,9 +45,11 @@ const int TIMEOUT = 1000;
 #include "BreakInterface.hh"
 #include "BreakResponseInterface.hh"
 #include "GtkUtil.hh"
+#include "Frame.hh"
 
 #include "CoreInterface.hh"
 #include "CoreFactory.hh"
+#include "ActivityMonitorInterface.hh"
 
 #ifdef HAVE_EXERCISES
 #include "Exercise.hh"
@@ -67,7 +69,8 @@ RestBreakWindow::RestBreakWindow(HeadInfo &head, bool ignorable,
   BreakWindow(BREAK_ID_REST_BREAK, head, ignorable, mode),
   timebar(NULL),
   progress_value(0),
-  progress_max_value(0)
+  progress_max_value(0),
+  is_flashing(false)
 {
   TRACE_ENTER("RestBreakWindow::RestBreakWindow");
   set_title(_("Rest break"));
@@ -91,11 +94,12 @@ RestBreakWindow::create_gui()
   timebar = manage(new TimeBar);
   vbox->pack_start(*timebar, false, false, 6);
 
-  Gtk::HButtonBox *button_box = create_break_buttons(TRUE, FALSE);
+  Gtk::HButtonBox *button_box = create_break_buttons(true, false);
   if (button_box)
     {
       vbox->pack_end(*manage(button_box), Gtk::SHRINK, 6);
     }
+
   return vbox;
 }
 
@@ -137,7 +141,9 @@ RestBreakWindow::start()
 //! Period timer callback.
 void
 RestBreakWindow::refresh()
-{
+{ 
+  BreakWindow::refresh();
+
   draw_time_bar();
 }
 
@@ -161,6 +167,27 @@ RestBreakWindow::draw_time_bar()
   sprintf(s, _("Rest break for %s"), Text::time_to_string(time, true).c_str());
   
   timebar->set_text(s);
+
+  CoreInterface *core = CoreFactory::get_core();
+  ActivityMonitorInterface *monitor = core->get_activity_monitor();
+  ActivityState state = monitor->get_current_state();
+  if (frame != NULL)
+    {
+      if (state == ACTIVITY_ACTIVE && !is_flashing)
+        {
+          frame->set_frame_color(Gdk::Color("orange"));
+          frame->set_frame_visible(true);
+          frame->set_frame_flashing(500);
+          is_flashing = true;
+        }
+      else if (state == ACTIVITY_IDLE && is_flashing)
+        {
+          frame->set_frame_flashing(0);
+          frame->set_frame_visible(false);
+          is_flashing = false;
+        }
+    }
+  
   timebar->update();
 }
 
@@ -252,12 +279,10 @@ RestBreakWindow::set_ignore_activity(bool i)
 {
   CoreInterface *core = CoreFactory::get_core();
   assert(core != NULL);
-  BreakInterface *bi = core->get_break(BREAK_ID_REST_BREAK);
-  assert(bi != NULL);
-
-  bi->set_insist_policy(i ?
-                        BreakInterface::INSIST_POLICY_IGNORE :
+  
+  core->set_insist_policy(i ?
+                        CoreInterface::INSIST_POLICY_IGNORE :
                         (block_mode != GUI::BLOCK_MODE_NONE
-                         ? BreakInterface::INSIST_POLICY_HALT
-                         : BreakInterface::INSIST_POLICY_RESET));
+                         ? CoreInterface::INSIST_POLICY_HALT
+                         : CoreInterface::INSIST_POLICY_RESET));
 }
