@@ -1,6 +1,6 @@
 // TimeEntry.cc --- Entry widget for time
 //
-// Copyright (C) 2002, 2003, 2004 Raymond Penners <raymond@dotsphinx.com>
+// Copyright (C) 2002, 2003, 2004, 2006 Raymond Penners <raymond@dotsphinx.com>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -13,7 +13,7 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// $Id: TimeEntry.cc,v 1.2 2004/04/03 15:55:33 rcaelers Exp $
+// $Id: TimeEntry.cc,v 1.3 2006/05/12 22:04:47 rcaelers Exp $
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -130,7 +130,8 @@ void
 TimeEntry::update(Gtk::SpinButton *spin)
 {
   // Needless to say, this kinda sucks.
-  const gchar *txt = spin->get_text().c_str();
+  Glib::ustring s = spin->get_text();
+  const gchar *txt = s.c_str();
   if (txt != NULL && *txt != 0)
     {
       gchar *err = NULL;
